@@ -2,14 +2,14 @@
  * @file configfile.h
  * @brief Config file handler 
  * @created 2005-01-22
- * @date 2007-09-29
- * @copyright 1991-2007 TLK Games
+ * @date 2014-07-27 
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.10 $
+ * @version $Revision: 24 $
  */
 /* 
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: configfile.h,v 1.10 2007/09/26 16:00:06 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: configfile.h 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,16 +47,18 @@
 #else
 #define MKDIR mkdir
 #endif
-#ifdef _WIN32
-#define CONFIG_DIR_NAME "tlkgames"
-#else
-#define CONFIG_DIR_NAME ".tlkgames"
-#endif
-#define CONFIG_FILE_NAME "tecnoballz.conf"
+//#ifdef _WIN32
+//#define CONFIG_DIR_NAME "tlkgames"
+//#else
+//#define CONFIG_DIR_NAME ".tlkgames"
+//#endif
+//#define CONFIG_FILE_NAME "tecnoballz.conf"
 
 class configfile:public virtual tecnoballz
 {
 private:
+  static const std::string CONF_DIR_NAME;
+  static const std::string CONF_FILENAME;
   typedef enum
   {
     LANGUAGE_EN,
@@ -69,8 +71,10 @@ private:
   static const char *language_to_string[MAX_OF_LANGUAGES]; 
   Uint32 language;
   static char stringname[7];
-  char config_dir[512];
-  char configname[512];
+  std::string conf_filename; 
+  std::string conf_dirname; 
+  //char config_dir[512];
+  //char configname[512];
   char thePlayer1[7];
   char thePlayer2[7];
   char thePlayer3[7];
@@ -87,14 +91,15 @@ public:
   void load ();
   void save ();
   Sint32 scan_arguments (Sint32 arg_count, char **arg_values);
-  char *get_player_name (Uint32 playernum);
-  void set_player_name (Uint32 playernum, char *name);
+  const char *get_player_name (Uint32 playernum);
+  void set_player_name (Uint32 playernum, const char *name);
   const char * get_language ();
 
 private:
   bool check_and_create_dir ();
   void resetvalue ();
   FILE *fopen_data (const char *rel_filename, const char *mode);
+  void get_fullpathname ();
 
 };
 #endif
