@@ -2,13 +2,13 @@
  * @file supervisor.h
  * @brief Virtual class for all supervisors 
  * @date 2007-10-02
- * @copyright 1991-2007 TLK Games
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.5 $
+ * @version $Revision$
  */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: supervisor.h,v 1.5 2007/10/02 11:25:37 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id$
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class supervisor:public virtual tecnoballz
 
   public:
     supervisor ();
-    virtual ~ supervisor ();
+    virtual ~ supervisor () = 0;
     void initialize ();
     void release ();
     virtual void first_init ();
