@@ -1,14 +1,14 @@
 /**
  * @file handler_keyboard.cc
  * @brief Handler of the keyboard and mouse
- * @date 2007-11-19
- * @copyright 1991-2007 TLK Games
+ * @date 2012-09-04 
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.20 $
+ * @version $Revision: 24 $
  */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: handler_keyboard.cc,v 1.20 2007/11/19 12:44:15 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: handler_keyboard.cc 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,8 +64,6 @@ handler_keyboard::handler_keyboard ()
 {
   object_init ();
   is_grab_input = false;
-  previous_mouse_x_coord = 0;
-  previous_mouse_y_coord = 0;
   mouse_x_offset = 0;
   mouse_y_offset = 0;
   /* x and y coordinates of the mouse */
@@ -210,13 +208,16 @@ handler_keyboard::get_instance ()
  * directly to the application
  * @param mode true to enable grab input, false to disable it
  */
+#ifdef UNDER_DEVELOPMENT
+void
+handler_keyboard::set_grab_input (bool)
+{
+  return;
+}
+#else
 void
 handler_keyboard::set_grab_input (bool mode)
 {
-
-#ifdef UNDER_DEVELOPMENT
-  return;
-#else
   if (mode)
     {
       is_grab_input = true;
@@ -230,8 +231,8 @@ handler_keyboard::set_grab_input (bool mode)
       is_grab_input = false;
       SDL_WM_GrabInput (SDL_GRAB_OFF);
     }
-#endif
 }
+#endif
 
 /**
  * Handle buttons of handheld video game console
@@ -564,6 +565,8 @@ handler_keyboard::read_events ()
           /* read the x and y coordinates of the mouse */
           mouse_x_coord = event.motion.x;
           mouse_y_coord = event.motion.y;
+          mouse_x_offset += event.motion.xrel;
+          mouse_y_offset += event.motion.yrel;
         }
         break;
 
@@ -1029,8 +1032,8 @@ handler_keyboard::clear_command_keys ()
     {
       SDL_WM_GrabInput (SDL_GRAB_ON);
     }
-  previous_mouse_x_coord = mouse_x_coord;
-  previous_mouse_y_coord = mouse_y_coord;
+  mouse_x_offset = 0;
+  mouse_y_offset = 0;
   is_key_waiting = true;
   wait_key_pressed = false;
 }
@@ -1142,15 +1145,26 @@ handler_keyboard::is_right_button_up (Sint32 * x_coord, Sint32 * y_coord)
 Sint32
 handler_keyboard::get_mouse_x_offset ()
 {
-  mouse_x_offset = mouse_x_coord - previous_mouse_x_coord;
-  mouse_y_offset = mouse_y_coord - previous_mouse_y_coord;
-  previous_mouse_x_coord = mouse_x_coord;
-  previous_mouse_y_coord = mouse_y_coord;
-  random_counter += previous_mouse_x_coord;
-  random_counter += previous_mouse_y_coord;
-  return mouse_x_offset;
+  Sint32 retval = mouse_x_offset;
+  random_counter += mouse_x_coord + mouse_x_offset;
+  mouse_x_offset = 0;
+  return retval;
 }
 
+/**
+* Caculate and return offset of vertical displacement of the mouse
+* @return the mouse vertical offset
+*/
+Sint32
+handler_keyboard::get_mouse_y_offset ()
+{
+  Sint32 retval = mouse_y_offset;
+  random_counter += mouse_y_coord + mouse_y_offset;
+  mouse_y_offset = 0;
+  return retval;
+}
+
+
 /**
  * Return absolute mouse y coordinate
  * @return the mouse pointer y coordinate
