@@ -1,14 +1,14 @@
 /** 
  * @file handler_players.cc 
  * @brief players handler 
- * @date 2007-10-06
- * @copyright 1991-2007 TLK Games
+ * @date 2012-09-05 
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.17 $
+ * @version $Revision: 24 $
  */
 /* 
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: handler_players.cc,v 1.17 2007/10/06 08:54:53 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: handler_players.cc 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,6 +128,7 @@ handler_players::reset_members ()
   score_value = 0;
   bonus_life_counter = 0;
   area_number = 1;
+  //area_number = 5; /*TEST*/
   /* level number into the current area */
   level_number = 1;
   number_of_lifes = initial_num_of_lifes;
@@ -158,7 +159,7 @@ handler_players::reset_members ()
  * @param name the name of the player
  */
 void
-handler_players::set_name (char *name)
+handler_players::set_name (const char *name)
 {
   for (Uint32 i = 0; i < PLAYER_NAME_LENGTH; i++)
     {
