@@ -2,14 +2,14 @@
  * @file handler_resources.cc 
  * @brief Handler of the files resources 
  * @created 2004-04-20 
- * @date 2007-10-18
- * @copyright 1991-2007 TLK Games
+ * @date 2014-07-20 
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.24 $
+ * @version $Revision: 24 $
  */
 /* 
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: handler_resources.cc,v 1.24 2007/10/29 13:18:53 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: handler_resources.cc 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "../include/bitmap_data.h"
 #include "../config.h"
 #include <string>
+#include <fstream>
 
 #ifndef DATADIR
 #define DATADIR "/usr/share/games/tecnoballz"
@@ -45,7 +46,10 @@
 #endif
 #endif
 
-char * handler_resources::fnamescore = SCOREFILE;
+handler_resources *
+handler_resources::handler_resources_singleton = NULL;
+
+const char * handler_resources::fnamescore = SCOREFILE;
 const char *
   handler_resources::folder_640 = "hires/";
 const char *
@@ -174,6 +178,23 @@ const char * handler_resources::texts_files[] =
  */
 handler_resources::handler_resources ()
 {
+  last_filesize_loaded = 0;
+  set_filesize_loaded(0);
+}
+
+/**
+ * Get the object instance
+ * handler_resources is a singleton
+ * @return the handler_resources object 
+ */
+handler_resources *
+handler_resources::get_instance ()
+{
+  if (NULL == handler_resources_singleton)
+    {
+      handler_resources_singleton = new handler_resources ();
+    }
+  return handler_resources_singleton;
 }
 
 /**
@@ -308,7 +329,6 @@ const char * handler_resources::folderlist[] =
 char *
 handler_resources::locate_data_file (const char *const name)
 {
-
 /*
   if (is_verbose)
     {
@@ -316,7 +336,7 @@ handler_resources::locate_data_file (const char *const name)
         cout << "(*) handler_resources::locate_data_file(" << name << ")" << std::
         endl;
     }
-*/
+ */
 
   /* clear path name string */
   for (Sint32 i = 0; i < 256; i++)
@@ -364,12 +384,12 @@ handler_resources::locate_data_file (const char *const name)
           strcat (pathname, subdir);
           strcat (pathname, name);
         }
-        /*
+      /*
       if (is_verbose)
         {
           std::cout << "handler_resources::locate_data_file() try " << pathname << std::endl;
         }
-        */
+      */
 #ifdef WIN32
       struct _stat s;
       if (_stat (pathname, &s) == 0 && !_S_ISDIR (s.st_mode))
@@ -380,14 +400,14 @@ handler_resources::locate_data_file (const char *const name)
       struct stat s;
       if (stat (pathname, &s) == 0 && !S_ISDIR (s.st_mode))
         {
-/*
+            /*
           if (is_verbose)
             {
               std::
                 cout << "handler_resources::locate_data_file(" << pathname <<
                 ") find!" << std::endl;
             }
-*/
+            */
           return pathname;
         }
 #endif
@@ -621,7 +641,7 @@ handler_resources::loadfile_with_lang (const char *const filename, Uint32 * cons
  * @param fname filename specified by path
  */
 char *
-handler_resources::load_file (char *fname)
+handler_resources::load_file (const char *fname)
 {
   return load_file (fname, &last_filesize_loaded);
 }
@@ -633,7 +653,7 @@ handler_resources::load_file (char *fname)
  * return a pointer to the file data 
 */
 char *
-handler_resources::load_file (char *fname, Uint32 * fsize)
+handler_resources::load_file (const char *fname, Uint32 * fsize)
 {
   /* locate a file under one of the data directories */
   char *pname = locate_data_file (fname);
@@ -648,7 +668,7 @@ handler_resources::load_file (char *fname, Uint32 * fsize)
     {
       std::cerr << "(!)handler_resources::load_file() " <<
         "can't open file " << fname
-        << "strerror:" << strerror (errno) << std::endl;
+        << "; error: " << strerror (errno) << std::endl;
       throw std::ios_base::failure ("(!)handler_resources::load_file() "
                                     "can't open a file!");
     }
@@ -688,7 +708,7 @@ handler_resources::load_file (char *fname, Uint32 * fsize)
         << "strerror:" << strerror (errno) << std::endl;
       throw std::ios_base::failure ("(!)handler_resources::load_file() "
                                     "can't read a file!");
-      return 0;
+      return NULL;
     }
 
   /* close the file */
@@ -706,6 +726,51 @@ handler_resources::get_filesize_loaded ()
   return last_filesize_loaded;
 }
 
+
+void
+handler_resources::set_filesize_loaded (Uint32 size)
+{
+  Uint32 i = size;
+  i++;
+  last_filesize_loaded = size;
+}
+
+char*
+handler_resources::read_complete_file (const char* filename )
+{
+  std::ifstream file (filename, std::ios::ate);
+  if (! file.is_open () )
+    {
+      std::cerr << "(!)handler_ressources::read_complete_file()"  
+        "can't open file '" << filename << "'" << std::endl;
+      //throw std::ios_base::failure ("(!)handler_ressources::read_complete_file() can't read a file!");
+      return NULL;
+    }
+  //Uint32 size = (Uint32) file.tellg();
+  std::ifstream::pos_type size = file.tellg();
+  //int filesize = (int)size;
+  //last_filesize_loaded = 1;
+  //last_filesize_loaded = 2;
+  //last_filesize_loaded = size;
+  char *buffer = NULL; 
+  try
+  {
+    buffer = new char[size];
+  }
+  catch (std::bad_alloc &)
+  {
+    file.close();
+    std::cerr << "(!)handler_resources::read_complete_file() " <<
+      "not enough memory to allocate " <<
+      size << " bytes!" << std::endl;
+    throw;
+  }
+  file.seekg (0, std::ios::beg);
+  file.read (buffer, size);
+  file.close();
+  return buffer;
+}
+
 /**
  * Load a precalculated sinus & cosinus table (1790 bytes <=> 895 values)
  * 0 to 511 cosinus / 383 to 894 sinus
@@ -759,6 +824,8 @@ handler_resources::load_high_score_file ()
 void
 handler_resources::save_high_score_file (char *buffer, Uint32 size)
 {
+  size_t left;
+  ssize_t bytes_written;
 #ifdef WIN32
   /* set umask so that files are group-writable */
   _umask (0002);
@@ -769,24 +836,36 @@ handler_resources::save_high_score_file (char *buffer, Uint32 size)
   if (fhand == -1)
     {
       fprintf (stderr,
-               "handler_resources::saveScores(): file:%s / error:%s\n",
+               "handler_resources::save_high_score_file(): file:%s / error:%s\n",
                fnamescore, strerror (errno));
     }
+  left = size;
+  while (left > 0)
+    {
 #ifdef WIN32
-  _write (fhand, buffer, size);
+      bytes_written = _write (fhand, buffer + size - left, left);
 #else
-  write (fhand, buffer, size);
+      bytes_written = write (fhand, buffer + size - left, left);
+      if (bytes_written == -1)
+        {
+          std::cerr << "(!)handler_resources::save_high_score_file():" <<
+             " filename: " << fnamescore << "; error: " << strerror (errno) << std::endl;  
+          close (fhand);
+          return;
+        }
+        left -= bytes_written;
+    }
 #endif
   if (close (fhand) == -1)
     {
       fprintf (stderr,
-               "handler_resources::saveScores(): file:%s / error:%s\n",
+               "handler_resources::save_high_score_file(): file:%s / error:%s\n",
                fnamescore, strerror (errno));
     }
   else
     {
       if (is_verbose)
-        fprintf (stdout, "handler_resources::saveScores(): "
+        fprintf (stdout, "handler_resources::save_high_score_file(): "
                  "file:%s size:%i\n", fnamescore, size);
     }
 }
