@@ -1,14 +1,14 @@
 /**
  * @file sprite_display_menu.cc 
  * @brief Sprite wich display text of the menu in the menu principal 
- * @date 2007-10-31
- * @copyright 1991-2007 TLK Games
+ * @date 2012-09-02
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.22 $
+ * @version $Revision$
  */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: sprite_display_menu.cc,v 1.22 2007/10/31 07:35:29 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id$
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -234,7 +234,7 @@ Uint32 sprite_display_menu::check_and_display ()
               for (j = 0; j < NUM_OF_COLUMNS; j++)
                 {
                   unsigned char pixel = color_cycling[color];
-                  char a = *(p++) - 32;
+                  a = *(p++) - 32;
                   if (a != 0)
                     {
                       b = c[a];
@@ -335,7 +335,7 @@ Uint32 sprite_display_menu::check_and_display ()
               for (j = 0; j < NUM_OF_COLUMNS; j++)
                 {
                   unsigned char pixel = color_cycling[color];
-                  char a = *(p++) - 32;
+                  a = *(p++) - 32;
                   if (a != 0)
                     {
                       b = c[a];
@@ -700,8 +700,8 @@ sprite_display_menu::draw_input_cursor ()
     {
       return;
     }
-  char z = 0xEE;
-  char *d =
+  unsigned char z = 0xEE;
+  unsigned char *d = (unsigned char *)
     text_offscreen->get_pixel_data (clear_zone_xcoord + xcurs * font_width,
                                     clear_zone_ycoord);
   Uint32 n = row_size;
