@@ -1,14 +1,14 @@
 /**
 * @file sprite_object.cc 
 * @brief Draw a sprite on the screen 
-* @date 2007-10-31
-* @copyright 1991-2007 TLK Games
+* @date 2014-07-27
+* @copyright 1991-2014 TLK Games
 * @author Bruno Ethvignot
-* @version $Revision: 1.43 $
+* @version $Revision: 24 $
 */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: sprite_object.cc,v 1.43 2007/10/31 07:35:29 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: sprite_object.cc 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,14 @@ sprite_object::sprite_object ()
   ombredecay = handler_display::SHADOWOFFY * resolution;
   ombrepixel = handler_display::SHADOW_PIX;
   ombrepixe4 = handler_display::SHADOWLONG;
+  sprite_height = 0;
+  sprite_width = 0;
+  screen_height = 0;
+  screen_width = 0;
+  x_maximum = 0;
+  y_maximum = 0;
+  x_minimum = 0;
+  y_minimum = 0;
   clear_sprite_members ();
 }
 
@@ -131,24 +139,16 @@ sprite_object::clear_sprite_members ()
   max_of_images = 0;
   frame_index = 0;
   is_enabled = false;
-  sprite_height = 0;
-  sprite_width = 0;
   drawing_values = (Sint16 **) NULL;
   drawing_data = (char **) NULL;
   drawing_pixels = (Sint16 **) NULL;
   collision_height = 0;
   collision_width = 0;
-  screen_height = 0;
-  screen_width = 0;
   frame_period = 1;
   x_coord = 0;
   y_coord = 0;
   display_pos = 0;
-  x_maximum = 0;
-  y_maximum = 0;
   frame_index_max = 0;
-  x_minimum = 0;
-  y_minimum = 0;
   frame_index_min = 0;
   offsetDest = 0;
   offsetSrce = 0;
@@ -304,8 +304,8 @@ sprite_object::init_common (surface_sdl * bitmap, bool shadow)
   max_of_images = 1;
   collision_height = sprite_height;
   collision_width = sprite_width;
-  x_maximum = screen_width - (Sint32) collision_width;
-  y_maximum = screen_height - (Sint32) collision_height;
+  x_maximum = screen_width -  collision_width;
+  y_maximum = screen_height - collision_height;
   offsetSrce = bitmap->get_line_modulo (sprite_width);
   offsetDest = game_screen->get_line_modulo (sprite_width);
 }
@@ -672,6 +672,25 @@ sprite_object::set_coordinates (Sint32 xcoord, Sint32 ycoord)
   y_coord = ycoord;
 }
 
+/**
+ * Initializes the maximum and minimum coordinates of the sprite
+ */
+void
+sprite_object::init_coords_max_min(Uint32 width_less)
+{
+  if (sprite_has_shadow)
+    {
+      x_minimum = ombredecax;
+    }
+  else 
+    {
+      x_minimum = 0;
+      y_minimum = 0;
+    }
+  x_maximum = screen_width - collision_width - width_less;
+  y_maximum = screen_height - collision_height;
+}
+
 /**
  * Set x coordinate of the sprite
  * @param xcoord the x coordinate in pixels
@@ -1431,7 +1450,7 @@ sprite_object::draw_shadow ()
       k = *(counters++);
       for (Sint32 j = 0; j < k; j++)
         {
-          *(screen32++) |= mask;
+           *(screen32++) |= mask;
         }
       /* number of contiguous bytes */
       k = *(counters++);
@@ -1720,6 +1739,83 @@ sprite_object::collision (sprite_object * sprite)
           y2 - (Sint32)collision_height < y1);
 }
 
+/**
+ * Check collision beetween a sprite and a segment
+ * @param sprite Pointer to a sprite object
+ * @return true if collision occurs, otherwise false
+ */
+bool
+sprite_object::collision (Sint32 x1, Sint32 y1, Sint32 x2, Sint32 y2)
+{
+  Sint32 xmin, xmax;
+  Sint32 ymin, ymax;
+
+  /* Swap points for x1 < x2 to be true */
+  if (x1 > x2)
+    {
+      Sint32 tmp = x2;
+      x2 = x1;
+      x1 = tmp;
+
+      tmp = y2;
+      y2 = y1;
+      y1 = tmp;
+    }
+  xmin = x1;
+  xmax = x2;
+
+  if (y1 < y2)
+    {
+      ymin = y1;
+      ymax = y2;
+    }
+  else
+    {
+      ymin = y2;
+      ymax = y1;
+    }
+
+  /* Condition sine qua none */
+  if (!(xmin < x_coord + (Sint32)collision_width &&
+        ymin < y_coord + (Sint32)collision_height &&
+        xmax > x_coord &&
+        ymax > y_coord))
+    {
+      return false;
+    }
+
+  /* Both points are in the "vertical band" */
+  if (xmin > x_coord && xmin < x_coord + (Sint32)collision_width &&
+      xmax > x_coord && xmax < x_coord + (Sint32)collision_width)
+    {
+      return true;
+    }
+
+  /* Check for diagonals and every remaining cases */
+  float alpha = (y2 - y1) / (x2 - x1);
+  Sint32 x0 = -alpha * x1 + y1;
+
+  if (x1 < x_coord)
+    {
+      Sint32 ytest = alpha * x_coord + x0;
+      if (ytest > y_coord && ytest < y_coord + (Sint32)collision_height)
+        {
+          return true;
+        }
+    }
+
+  if (x2 > x_coord + (Sint32)collision_width)
+    {
+      Sint32 ytest = alpha * (x_coord + (Sint32)collision_width) + x0;
+      if (ytest > y_coord && ytest < y_coord + (Sint32)collision_height)
+        {
+          return true;
+        }
+    }
+
+  return false;
+}
+
 /**
  * Set the frame delay and period, the speed of animation
  * @param delay time delay before next image
