@@ -2,14 +2,14 @@
  * @file supervisor_map_editor.cc
  * @brief The tile map editor for the menu and guardians levels
  * @created 2004-09-13
- * @date 2007-11-18
- * @copyright 1991-2007 TLK Games
+ * @date 2012-08-19
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.25 $
+ * @version $Revision$
  */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: supervisor_map_editor.cc,v 1.25 2007/11/18 16:13:20 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id$
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -529,8 +529,8 @@ supervisor_map_editor::highlight_selection ()
     {
       return;
     }
-  Uint32 y1 = current_selection->y1 - current_selection->y_offset;
-  Uint32 y2 = current_selection->y2 - current_selection->y_offset;
+  Sint32 y1 = current_selection->y1 - current_selection->y_offset;
+  Sint32 y2 = current_selection->y2 - current_selection->y_offset;
 
   if (x1 > x2)
     {
@@ -555,7 +555,7 @@ supervisor_map_editor::highlight_selection ()
 
 
   /* top border */
-  if (y1 >= 0 && y1 < screen_height)
+  if (y1 >= 0 && y1 < (Sint32)screen_height)
     {
       screen = game_screen->get_pixel_data (x1, y1);
       cycle_delay = 0;
@@ -577,10 +577,10 @@ supervisor_map_editor::highlight_selection ()
   /* right border */
   Uint32 rowsize = game_screen->get_row_size ();
   screen = game_screen->get_pixel_data (x2 - 1, y1 + 1);
-  for (Uint32 i = 1; i < height; i++)
+  for (Sint32 i = 1; i < (Sint32)height; i++)
     {
       unsigned char pixel = cycled_colors_list[color];
-      if (y1 + i >= 0 && y1 + i < screen_height)
+      if ((y1 + i) >= 0 && (y1 + i) <  (Sint32) screen_height)
         {
           *screen = pixel;
         }
@@ -596,7 +596,7 @@ supervisor_map_editor::highlight_selection ()
     }
 
   /* bottom border */
-  if (y2 >= 0 && y2 < screen_height)
+  if (y2 >= 0 && y2 < (Sint32)screen_height)
     {
       screen = game_screen->get_pixel_data (x1, y2);
       for (Sint32 i = width - 1; i >= 0; i--)
@@ -616,10 +616,10 @@ supervisor_map_editor::highlight_selection ()
 
   /* left border */
   screen = game_screen->get_pixel_data (x1, y2 - 1);
-  for (Uint32 i = 1; i < height; i++)
+  for (Sint32 i = 1; i < (Sint32)height; i++)
     {
       unsigned char pixel = cycled_colors_list[color];
-      if (y2 - i >= 0 && y2 - i < screen_height)
+      if ((y2 - i) >= 0 && (y2 - i) < (Sint32)screen_height)
         {
           *screen = pixel;
         }
@@ -774,6 +774,8 @@ bool supervisor_map_editor::save_tilesmap ()
 //map_size = map_size * 2;
   Uint32
   bytes_size = map_size * sizeof (Uint16);
+  size_t left;
+  ssize_t bytes_written;
 
   /*
     Uint16 *map2 = new Uint16[map_size];
@@ -832,7 +834,7 @@ bool supervisor_map_editor::save_tilesmap ()
 #else
   umask (0002);
 #endif
-  char *
+  const char *
   filename = "edmap.data";
   Sint32
   handle = open (filename, O_WRONLY | O_CREAT, 00666);
@@ -843,10 +845,23 @@ bool supervisor_map_editor::save_tilesmap ()
       delete[]filedata;
       return false;
     }
+  left = bytes_size;
+  while (left > 0)
+    {
 #ifdef WIN32
-  _write (handle, filedata, bytes_size);
+      bytes_written = _write (handle, filedata + bytes_size - left, left);
 #else
-  write (handle, filedata, bytes_size);
+      bytes_written = write (handle, filedata + bytes_size - left, left);
+      if (bytes_written == -1)
+       {
+         std::cerr << "(!)supervisor_map_editor::save_tilesmap():" <<
+          " filename: " << filename << "; error: " << strerror (errno);  
+         close (handle);
+         delete[]filedata;
+         return false;
+       }
+      left -= bytes_written;
+    }
 #endif
   if (close (handle) == -1)
     {
