@@ -1,14 +1,14 @@
 /**
  * @file supervisor_shop.cc
  * @brief Shop supervisor
- * @date 2007-11-17
- * @copyright 1991-2007 TLK Games
+ * @date 2012-08-19
+ * @copyright 1991-2014 TLK Games
  * @author Bruno Ethvignot
- * @version $Revision: 1.53 $
+ * @version $Revision: 24 $
  */
 /*
- * copyright (c) 1991-2007 TLK Games all rights reserved
- * $Id: supervisor_shop.cc,v 1.53 2007/11/17 21:37:44 gurumeditation Exp $
+ * copyright (c) 1991-2014 TLK Games all rights reserved
+ * $Id: supervisor_shop.cc 24 2014-09-28 15:30:04Z bruno.ethvignot@gmail.com $
  *
  * TecnoballZ is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,8 +128,8 @@ supervisor_shop::first_init ()
   /* copy name player into menu text */
   display_text->print_to_string (current_player->get_name (),
                                  box_texts[TEXT_WELCOME]);
-  char * dest;
-  dest = current_player->get_name ();
+  //char * dest;
+  //dest = current_player->get_name ();
   display_text->print_int_to_string (current_player->get_num_of_lifes (),
                                      2, box_texts[TEXT_LIVES_LEFT]);
   display_text->print_int_to_string (MAX_OF_CAPSULES_BOUGHT, 2,
@@ -699,7 +699,7 @@ supervisor_shop::purchase_bonus_capsule (Sint32 capsule_id)
 void
 supervisor_shop::display_sales_confirmation (Sint32 option_index)
 {
-  char *text = box_texts[led_index_to_text_index[option_index]];
+  char *text = box_texts[(int)led_index_to_text_index[option_index]];
   put_current_text (text);
 }
 
@@ -866,6 +866,7 @@ supervisor_shop::capsule_drag_and_drop ()
         }
       else
         {
+          i = 0;
           while (available_options_id[i] != sprite_capsule::LEAVE_SHOP)
             {
               if (available_options_id[i] == drop_id)
@@ -1081,7 +1082,7 @@ supervisor_shop::options_prices[] =
 /**
  * Indexes of the texts used for sales confirmation messages
  */
-char
+unsigned char
 supervisor_shop::led_index_to_text_index[] =
 {
   /* S+/F1/F2/RW/B2/B3 */
